@@ -377,6 +377,12 @@ main (int argc, char **argv)
                 exit (1);
         }
 
+        gsm_util_export_activation_environment (NULL);
+
+#ifdef HAVE_SYSTEMD
+        gsm_util_export_user_environment (NULL);
+#endif
+
         {
                 gchar *ibus_path;
 
